from os import name
from setuptools import setup

setup(name= 'aditya_distribution',
    version = '0.1',
    description='Gaussian Distributions',
    packages=['aditya_distribution'],
    author = 'Aditya Khadke',
    author_email='Aditya.Khadke04@gmail.com',
   zip_safe=False)
